countSync method
Returns the total number of objects in this collection.
For non-web apps, this method is extremely fast and independent of the number of objects in the collection.
Implementation
@override
int countSync() {
return _spanHelper.syncWrapInSpan(
'countSync',
() {
return _isarCollection.countSync();
},
dbName: _dbName,
collectionName: name,
);
}